==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetEvaluationPlanCognitiveInteractionTask.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlanCognitiveInteractionTask] (
    @VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL -- EVALUATION PLAN ID
)
AS
BEGIN
SET NOCOUNT ON
	-- ESTE SP TIENE POR FINALIDAD RETORNAR LA LISTA DE INTERACCIONES CRUZADA CON LOS MODELOS NLU QUE SE VAN A EVALUAR

	-- BUSCAMOS LOS MODELOS ASOCIADOS AL PLAN Y LAS HABILIDADES QUE LO APLICAN
	SELECT DISTINCT HAQ.VCC										'vcc'
					,N.[Name] + '|' + I.[Name]					'cognitiveId'
					,N.[Name]									'nluId'
					,N.[AppId]									'appId'
					,I.[IntentId]								'intentId'
					,'ABILITY'								'mainTarget'
					,STUFF(
						(
							SELECT DISTINCT ',' + INNER_HAQ.[AbilityId]
								FROM [dbo].[HistoricAbilityQuery] INNER_HAQ (NOLOCK)
								WHERE INNER_HAQ.[VCC] = HAQ.[VCC]
									AND INNER_HAQ.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
									AND INNER_HAQ.[QueryContent] = N.[Name] + '|' + I.[Name]
							FOR XML PATH(''), TYPE
						).value('.', 'NVARCHAR(MAX)'), 
						1, 
						1, 
						''
					)											'abilities'
					,CONVERT(BIT, 1) 							'needRequest'
		INTO #EVALUATION_PLAN_MODELS 
		FROM [HistoricAbilityQuery] HAQ (NOLOCK) 
		INNER JOIN [HistoricAbility] HA (NOLOCK)
			ON HA.[VCC] = HAQ.[VCC]
				AND HA.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
				AND HA.[ID] = HAQ.[AbilityId]
		INNER JOIN [dbo].[Intent] I (NOLOCK)
			ON I.[VCC] = HAQ.[VCC]
				AND I.[IntentId] = HAQ.[QueryId]
		INNER JOIN [dbo].[NLU] N (NOLOCK)
			ON N.[VCC] = HAQ.[VCC]
				AND N.[AppId] = I.[AppId]
		WHERE HAQ.[VCC] = @VCC
			AND HAQ.[EvaluationPlanId] = @ID
			AND HA.[AnalysisType] = 'COGNITIVE'

	-- DROP TABLE #EVALUATION_PLAN_MODELS 
	-- SELECT * FROM #EVALUATION_PLAN_MODELS 

	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO CALL QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AU.Campaign								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,AU.Section									'section'
			,AU.Part									'part'
			,NULL										'folder'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AU.[FileName]								'fileName'
			--,EPM.[cognitiveId]						-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON IEP.Instance = EP.Instance 
			AND IEP.IdEvaluationPlan = EP.Id
	INNER JOIN [dbo].[Audio] AU (NOLOCK) 
		ON AU.VCC = EP.Instance
			AND AU.ID = IEP.IdInteraction 
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @ID
		AND AU.[IsTranscribed] = 1
	
	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO TEXT QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AI.[Campaign]								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,NULL										'section'
			,NULL										'part'
			,AI.[EndDate]								'endDate'
			,AI.[Folder]								'folder'
			,AI.[DispositionCode]						'dispositionCode'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AI.[FileName]								'fileName'
			--,F.[cognitiveId]							-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON EP.Instance = IEP.Instance 
			AND EP.Id = IEP.IdEvaluationPlan
	INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK) 
		ON EP.Instance = AI.VCC 
			AND IEP.IdInteraction = AI.ID
			AND IEP.FormattedEndDate = AI.Folder
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @ID
		AND AI.[IsTranscribed] = 1

SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEvaluationPlanCognitiveInteractionTask.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlanCognitiveInteractionTask] (
    @VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL -- EVALUATION PLAN ID
)
AS
BEGIN
SET NOCOUNT ON
	-- ESTE SP TIENE POR FINALIDAD RETORNAR LA LISTA DE INTERACCIONES CRUZADA CON LOS MODELOS NLU QUE SE VAN A EVALUAR

	-- BUSCAMOS LOS MODELOS ASOCIADOS AL PLAN Y LAS HABILIDADES QUE LO APLICAN
	SELECT DISTINCT HAQ.VCC										'vcc'
					-- ,N.[Name] + '|' + I.[Name]					'cognitiveId'
					,N.[Name]									'nluId'
					,N.[AppId]									'appId'
					,I.[IntentId]								'intentId'
					,'ABILITY'								'mainTarget'
					,STUFF(
						(
							SELECT DISTINCT ',' + INNER_HAQ.[AbilityId]
								FROM [dbo].[HistoricAbilityQuery] INNER_HAQ (NOLOCK)
								WHERE INNER_HAQ.[VCC] = HAQ.[VCC]
									AND INNER_HAQ.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
									-- AND INNER_HAQ.[QueryContent] = N.[Name] + '|' + I.[Name]
							FOR XML PATH(''), TYPE
						).value('.', 'NVARCHAR(MAX)'), 
						1, 
						1, 
						''
					)											'abilities'
					,CONVERT(BIT, 1) 							'needRequest'
		INTO #EVALUATION_PLAN_MODELS 
		FROM [HistoricAbilityQuery] HAQ (NOLOCK) 
		INNER JOIN [HistoricAbility] HA (NOLOCK)
			ON HA.[VCC] = HAQ.[VCC]
				AND HA.[EvaluationPlanId] = HAQ.[EvaluationPlanId]
				AND HA.[ID] = HAQ.[AbilityId]
		INNER JOIN [dbo].[Intent] I (NOLOCK)
			ON I.[VCC] = HAQ.[VCC]
				AND I.[IntentId] = HAQ.[QueryId]
		INNER JOIN [dbo].[NLU] N (NOLOCK)
			ON N.[VCC] = HAQ.[VCC]
				AND N.[AppId] = I.[AppId]
		WHERE HAQ.[VCC] = @VCC
			AND HAQ.[EvaluationPlanId] = @ID
			AND HA.[AnalysisType] = 'COGNITIVE'

	-- DROP TABLE #EVALUATION_PLAN_MODELS 
	-- SELECT * FROM #EVALUATION_PLAN_MODELS 

	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO CALL QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AU.Campaign								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,AU.Section									'section'
			,AU.Part									'part'
			,NULL										'folder'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AU.[FileName]								'fileName'
			--,EPM.[cognitiveId]						-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON IEP.Instance = EP.Instance 
			AND IEP.IdEvaluationPlan = EP.Id
	INNER JOIN [dbo].[Audio] AU (NOLOCK) 
		ON AU.VCC = EP.Instance
			AND AU.ID = IEP.IdInteraction 
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @ID
		AND AU.[IsTranscribed] = 1
	
	-- ESTE SCRIPT RECUPERA LAS INTERACCIONES TIPO TEXT QUE ENTRARAN A LA EVALUACION COGNITIVA
	SELECT DISTINCT
			EP.Instance									'vcc'
			,EP.ProcessId								'processId'
			,'EVALUATION_PLAN'							'batchTypeName'
			,AI.[Campaign]								'campaign'
			,IEP.[InteractionType]						'interactionType'
			,EP.[Id]									'evaluationPlanId'
			,IEP.IdInteraction							'id'
			,NULL										'section'
			,NULL										'part'
			,AI.[EndDate]								'endDate'
			,AI.[Folder]								'folder'
			,AI.[DispositionCode]						'dispositionCode'
			,EPM.nluId									'nluId'
			,EPM.appId									'appId'
			,EPM.[mainTarget]							'mainTarget'
			,AI.[FileName]								'fileName'
			--,F.[cognitiveId]							-- CREA MAS REGISTROS DE LOS NECESARIOS AL INICIAR EL TASK
			,V.[CognitiveEngine]						'cognitiveEngine'
			,EPM.[abilities]							'abilities'
			,EPM.[needRequest]							'needRequest'
	FROM [EvaluationPlan] EP (NOLOCK)
	INNER JOIN [InteractionEvaluationPlan] IEP (NOLOCK) 
		ON EP.Instance = IEP.Instance 
			AND EP.Id = IEP.IdEvaluationPlan
	INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK) 
		ON EP.Instance = AI.VCC 
			AND IEP.IdInteraction = AI.ID
			AND IEP.FormattedEndDate = AI.Folder
	INNER JOIN #EVALUATION_PLAN_MODELS EPM 
		ON EPM.[vcc] = EP.[Instance]
			--AND EPM.[cognitiveId] = HAQ.[QueryContent] 
			--AND EPM.[intentId] = HAQ.[QueryId] 
	LEFT JOIN [dbo].[VCC] V (NOLOCK)
		ON V.[ID] = EP.[Instance]
	WHERE EP.[Instance] = @VCC
		AND EP.[ID] = @ID
		AND AI.[IsTranscribed] = 1

SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
